@@ -70,6 +70,7 @@ new LambdaToStepFunction(scope: Construct, id: string, props: LambdaToStepFuncti
 |:-------------|:----------------|-----------------|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
 |stateMachine|[`sfn.StateMachine`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachine.html)|Returns an instance of StateMachine created by the construct.|
+|stateMachineLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for StateMachine|
 |cloudwatchAlarms|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of alarms created by the construct.
 
 ## Default settings
@@ -109,6 +110,7 @@ from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_lambda
+import aws_cdk.aws_logs
 import aws_cdk.aws_stepfunctions
 import aws_cdk.core
 
@@ -169,6 +171,11 @@ class LambdaToStepFunction(
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return jsii.get(self, "stateMachine")
 
+    @builtins.property
+    @jsii.member(jsii_name="stateMachineLogGroup")
+    def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
+        return jsii.get(self, "stateMachineLogGroup")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-lambda-step-function.LambdaToStepFunctionProps",
